Check Cached Dir
cache_check.RdChecks for the presence of a cache dir. If interactive and not present, asks user if it should be created. If non-interactive and not present, it is created automatically.

cache_check.RdChecks for the presence of a cache dir. If interactive and not present, asks user if it should be created. If non-interactive and not present, it is created automatically.