Find GH username from repository and full name
gh_search.RdLook up users of a repository and match to a name. Try with and without initials.
Usage
gh_search(name, pkg = NULL, owner = "ropensci", open_browser = interactive())
gh_search.RdLook up users of a repository and match to a name. Try with and without initials.
gh_search(name, pkg = NULL, owner = "ropensci", open_browser = interactive())